Documentation
¶
Index ¶
- Constants
- func ConvertFromGrams(weight float64, toUnit string) float64
- func ConvertToGrams(weight float64, fromUnit string) float64
- func ConvertWeightUnit(unit string) string
- func FindItemIDByItemName(inventories dataset.Inventories, itemname string) uint
- func FindPackIDByPackName(packs dataset.Packs, packname string) uint
- func FindUserIDByUsername(users []dataset.User, username string) uint
- func FormatWeight(weightInGrams float64, displayUnit string) string
- func GenerateRandomCode(length int) (string, error)
- func IsValidEmail(email string) bool
- func StringToUint(s string) (uint, error)
- type EmailSender
- type SMTPClient
Constants ¶
const ( // Grams to other units GramsPerOunce = 28.3495 GramsPerPound = 453.592 )
Weight conversion constants
Variables ¶
This section is empty.
Functions ¶
func ConvertFromGrams ¶ added in v0.9.0
ConvertFromGrams converts a weight from grams to the specified unit
func ConvertToGrams ¶ added in v0.9.0
ConvertToGrams converts a weight from any unit to grams
func ConvertWeightUnit ¶
func FindItemIDByItemName ¶ added in v0.4.0
func FindItemIDByItemName(inventories dataset.Inventories, itemname string) uint
func FindPackIDByPackName ¶ added in v0.4.0
func FindUserIDByUsername ¶ added in v0.4.0
func FormatWeight ¶ added in v0.9.0
FormatWeight formats a weight in grams to a human-readable string
func GenerateRandomCode ¶ added in v0.3.0
func IsValidEmail ¶ added in v0.4.1
func StringToUint ¶
Types ¶
type EmailSender ¶ added in v0.3.0
EmailSender defines the interface for sending emails. Needed for testing without real SMTP server.
type SMTPClient ¶ added in v0.3.0
type SMTPClient struct {
Server dataset.MailServer
}
SMTPClient struct implements EmailSender interface.
func (*SMTPClient) SendEmail ¶ added in v0.3.0
func (s *SMTPClient) SendEmail(to, subject, body string) error
SendMail sends an email using the SMTP protocol.
Click to show internal directories.
Click to hide internal directories.